summaryrefslogtreecommitdiffstats
path: root/sandbox
diff options
context:
space:
mode:
Diffstat (limited to 'sandbox')
-rw-r--r--sandbox/src/dep_test.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/sandbox/src/dep_test.cc b/sandbox/src/dep_test.cc
index 62eeb1f..7d57c6e 100644
--- a/sandbox/src/dep_test.cc
+++ b/sandbox/src/dep_test.cc
@@ -166,8 +166,8 @@ SBOX_TESTS_COMMAND int CheckDepLevel(int argc, wchar_t **argv) {
} // namespace
-// This test fails. See bug 1275842
-TEST_F(DepTest, FAILS_TestDepDisable) {
+// This test is disabled. See bug 1275842
+TEST_F(DepTest, DISABLED_TestDepDisable) {
TestRunner runner(JOB_UNPROTECTED, USER_INTERACTIVE, USER_INTERACTIVE);
runner.SetTimeout(INFINITE);